# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.agents_v1_api import AgentsV1Api


class TestAgentsV1Api(unittest.TestCase):
    """AgentsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = AgentsV1Api()

    def tearDown(self) -> None:
        pass

    def test_get_registered_agent_by_id(self) -> None:
        """Test case for get_registered_agent_by_id

        Get A Registered Agent By Its Id.
        """
        pass

    def test_list_agents_for_workspace(self) -> None:
        """Test case for list_agents_for_workspace

        List All Agents For A Workspace.
        """
        pass

    def test_list_data_sources_for_workspace(self) -> None:
        """Test case for list_data_sources_for_workspace

        List All Registered Agent Data Sources For A Workspace.
        """
        pass

    def test_list_llm_models_for_workspace(self) -> None:
        """Test case for list_llm_models_for_workspace

        List All Registered Agent Llm Models For A Workspace.
        """
        pass

    def test_list_sub_agents_for_workspace(self) -> None:
        """Test case for list_sub_agents_for_workspace

        List All Registered Agent Sub-Agents For A Workspace.
        """
        pass

    def test_list_tools_for_workspace(self) -> None:
        """Test case for list_tools_for_workspace

        List All Registered Agent Tools For A Workspace.
        """
        pass

    def test_list_unregistered_agents_for_workspace(self) -> None:
        """Test case for list_unregistered_agents_for_workspace

        List All Unregistered Agents For A Workspace.
        """
        pass

    def test_put_agents(self) -> None:
        """Test case for put_agents

        Upsert Agents.
        """
        pass

    def test_update_unregistered_agent(self) -> None:
        """Test case for update_unregistered_agent

        Update An Unregistered Agent.
        """
        pass


if __name__ == '__main__':
    unittest.main()
