# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.resource_list_policy import ResourceListPolicy

class TestResourceListPolicy(unittest.TestCase):
    """ResourceListPolicy unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResourceListPolicy:
        """Test ResourceListPolicy
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResourceListPolicy`
        """
        model = ResourceListPolicy()
        if include_optional:
            return ResourceListPolicy(
                records = [
                    arthur_client.api_bindings.models.policy.Policy(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        organization_id = '', 
                        name = '', 
                        description = '', 
                        owner_group_id = '', 
                        webhook_id = '', 
                        enforcement_delay_days = 56, 
                        alert_rules = [
                            arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                threshold = 1.337, 
                                bound = 'upper_bound', 
                                query = '', 
                                metric_name = '', )
                            ], 
                        attestation_rules = [
                            arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                validity_period_days = 56, )
                            ], 
                        last_updated_by_user_id = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, )
            )
        else:
            return ResourceListPolicy(
                records = [
                    arthur_client.api_bindings.models.policy.Policy(
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        id = '', 
                        organization_id = '', 
                        name = '', 
                        description = '', 
                        owner_group_id = '', 
                        webhook_id = '', 
                        enforcement_delay_days = 56, 
                        alert_rules = [
                            arthur_client.api_bindings.models.policy_alert_rule.PolicyAlertRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                threshold = 1.337, 
                                bound = 'upper_bound', 
                                query = '', 
                                metric_name = '', )
                            ], 
                        attestation_rules = [
                            arthur_client.api_bindings.models.policy_attestation_rule.PolicyAttestationRule(
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                policy_id = '', 
                                name = '', 
                                description = '', 
                                validity_period_days = 56, )
                            ], 
                        last_updated_by_user_id = '', )
                    ],
                pagination = arthur_client.api_bindings.models.pagination.Pagination(
                    page = 56, 
                    page_size = 56, 
                    total_pages = 56, 
                    total_records = 56, ),
        )
        """

    def testResourceListPolicy(self):
        """Test ResourceListPolicy"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
