# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.policies_v1_api import PoliciesV1Api


class TestPoliciesV1Api(unittest.TestCase):
    """PoliciesV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = PoliciesV1Api()

    def tearDown(self) -> None:
        pass

    def test_check_assignment_compliance(self) -> None:
        """Test case for check_assignment_compliance

        Check Assignment Compliance
        """
        pass

    def test_check_model_compliance(self) -> None:
        """Test case for check_model_compliance

        Check Model Compliance
        """
        pass

    def test_check_policy_compliance(self) -> None:
        """Test case for check_policy_compliance

        Check Policy Compliance
        """
        pass

    def test_create_attestation(self) -> None:
        """Test case for create_attestation

        Create Attestation
        """
        pass

    def test_create_policy(self) -> None:
        """Test case for create_policy

        Create Policy
        """
        pass

    def test_create_policy_alert_rule(self) -> None:
        """Test case for create_policy_alert_rule

        Create Policy Alert Rule
        """
        pass

    def test_create_policy_assignments(self) -> None:
        """Test case for create_policy_assignments

        Create Policy Assignments
        """
        pass

    def test_create_policy_attestation_rule(self) -> None:
        """Test case for create_policy_attestation_rule

        Create Policy Attestation Rule
        """
        pass

    def test_delete_policy(self) -> None:
        """Test case for delete_policy

        Delete Policy
        """
        pass

    def test_delete_policy_alert_rule(self) -> None:
        """Test case for delete_policy_alert_rule

        Delete Policy Alert Rule
        """
        pass

    def test_delete_policy_assignment(self) -> None:
        """Test case for delete_policy_assignment

        Delete Policy Assignment
        """
        pass

    def test_delete_policy_attestation_rule(self) -> None:
        """Test case for delete_policy_attestation_rule

        Delete Policy Attestation Rule
        """
        pass

    def test_get_policy(self) -> None:
        """Test case for get_policy

        Get Policy
        """
        pass

    def test_get_policy_alert_rule(self) -> None:
        """Test case for get_policy_alert_rule

        Get Policy Alert Rule
        """
        pass

    def test_get_policy_assignment(self) -> None:
        """Test case for get_policy_assignment

        Get Policy Assignment
        """
        pass

    def test_get_policy_attestation_rule(self) -> None:
        """Test case for get_policy_attestation_rule

        Get Policy Attestation Rule
        """
        pass

    def test_list_assignment_attestations(self) -> None:
        """Test case for list_assignment_attestations

        List Assignment Attestations
        """
        pass

    def test_list_model_attestations(self) -> None:
        """Test case for list_model_attestations

        List Model Attestations
        """
        pass

    def test_list_model_policy_assignments(self) -> None:
        """Test case for list_model_policy_assignments

        List Model Policy Assignments
        """
        pass

    def test_list_policies(self) -> None:
        """Test case for list_policies

        List Policies
        """
        pass

    def test_list_policy_alert_rules(self) -> None:
        """Test case for list_policy_alert_rules

        List Policy Alert Rules
        """
        pass

    def test_list_policy_assignments(self) -> None:
        """Test case for list_policy_assignments

        List Policy Assignments
        """
        pass

    def test_list_policy_attestation_rules(self) -> None:
        """Test case for list_policy_attestation_rules

        List Policy Attestation Rules
        """
        pass

    def test_list_workspace_policy_assignments(self) -> None:
        """Test case for list_workspace_policy_assignments

        List Workspace Policy Assignments
        """
        pass

    def test_set_compliance_status(self) -> None:
        """Test case for set_compliance_status

        Set Compliance Status
        """
        pass

    def test_update_policy(self) -> None:
        """Test case for update_policy

        Update Policy
        """
        pass

    def test_update_policy_alert_rule(self) -> None:
        """Test case for update_policy_alert_rule

        Update Policy Alert Rule
        """
        pass

    def test_update_policy_attestation_rule(self) -> None:
        """Test case for update_policy_attestation_rule

        Update Policy Attestation Rule
        """
        pass


if __name__ == '__main__':
    unittest.main()
